<?php

namespace Litecms\Description\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Description\Models\Description;

class DescriptionPolicy
{

    /**
     * Determine if the given user can view the description.
     *
     * @param UserPolicy $user
     * @param Description $description
     *
     * @return bool
     */
    public function view(UserPolicy $user, Description $description)
    {
        if ($user->canDo('description.description.view') && $user->isAdmin()) {
            return true;
        }

        return $description->user_id == user_id() && $description->user_type == user_type();
    }

    /**
     * Determine if the given user can create a description.
     *
     * @param UserPolicy $user
     * @param Description $description
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('description.description.create');
    }

    /**
     * Determine if the given user can update the given description.
     *
     * @param UserPolicy $user
     * @param Description $description
     *
     * @return bool
     */
    public function update(UserPolicy $user, Description $description)
    {
        if ($user->canDo('description.description.edit') && $user->isAdmin()) {
            return true;
        }

        return $description->user_id == user_id() && $description->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given description.
     *
     * @param UserPolicy $user
     * @param Description $description
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Description $description)
    {
        return $description->user_id == user_id() && $description->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given description.
     *
     * @param UserPolicy $user
     * @param Description $description
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Description $description)
    {
        if ($user->canDo('description.description.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given description.
     *
     * @param UserPolicy $user
     * @param Description $description
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Description $description)
    {
        if ($user->canDo('description.description.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
