<?php

namespace Litecms\Description\Providers;

use Illuminate\Support\ServiceProvider;

class DescriptionServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'description');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'description');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.description', function ($app) {
            return $this->app->make('Litecms\Description\Description');
        });

                // Bind Description to repository
        $this->app->bind(
            'Litecms\Description\Interfaces\DescriptionRepositoryInterface',
            \Litecms\Description\Repositories\Eloquent\DescriptionRepository::class
        );

        $this->app->register(\Litecms\Description\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\Description\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\Description\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.description'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/description.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/description')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/description')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
